/*
 * Copyright 2021-2021 Alfresco Software, Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.alfresco.event.sdk.model.v1.model;

import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import java.util.List;
import java.util.Objects;

/**
 * Base node resource object representing the common attributes of the resource affected.
 */
public abstract class AbstractNodeResource implements Resource {

    protected final String id;

    // Only relevant for certain resources
    @JsonInclude(Include.NON_NULL)
    protected final List<String> primaryHierarchy;

    public AbstractNodeResource(final String id) {
        this(id, null);
    }

    public AbstractNodeResource(final String id, final List<String> primaryHierarchy) {
        this.id = id;
        this.primaryHierarchy = primaryHierarchy;
    }

    public String getId() {
        return id;
    }

    public List<String> getPrimaryHierarchy() {
        return primaryHierarchy;
    }

    @Override
    public boolean equals(final Object o) {
        if (this == o) {
            return true;
        }
        if (!(o instanceof AbstractNodeResource)) {
            return false;
        }
        final AbstractNodeResource resource = (AbstractNodeResource) o;
        return Objects.equals(id, resource.id)
                && Objects.equals(primaryHierarchy, resource.primaryHierarchy);
    }

    @Override
    public int hashCode() {
        return Objects.hash(id, primaryHierarchy);
    }
}
